@@ -240,6 +240,11 @@ class IGithubRepo(metaclass=abstracts.Interface):
         """Fetch a release for this repo."""
         raise NotImplementedError
 
+    @abstracts.interfacemethod
+    async def releases(self, name: str) -> "IGithubIterator":
+        """Fetch releases for this repo."""
+        raise NotImplementedError
+
     @abstracts.interfacemethod
     async def tag(self, name: str) -> "IGithubTag":
         """Fetch a tag for this repo."""
